@@ -641,6 +641,7 @@ def job_fields_to_attrs(fields):
         "id.dec": (),
         "id.hex": (),
         "id.f58": (),
+        "id.f58plain": (),
         "id.emoji": (),
         "id.kvs": (),
         "id.words": (),
@@ -736,6 +737,7 @@ class JobInfoFormat(flux.util.OutputFormat):
         "id.dec": "JOBID",
         "id.hex": "JOBID",
         "id.f58": "JOBID",
+        "id.f58plain": "JOBID",
         "id.emoji": "JOBID",
         "id.kvs": "JOBID",
         "id.words": "JOBID",
