@@ -438,95 +438,7 @@ int flux_pollfd (flux_t *h);
 
 void flux_get_msgcounters (flux_t *h, flux_msgcounters_t *mcs);
 void flux_clr_msgcounters (flux_t *h);
-# 665 "/__w/flux-python/flux-python/src/_core_clean.h"
-typedef struct flux_buffer flux_buffer_t;
-
-
-
-flux_buffer_t *flux_buffer_create (int size);
-
-void flux_buffer_destroy (void *fb);
-
-
-int flux_buffer_size (flux_buffer_t *fb);
-
-
-int flux_buffer_bytes (flux_buffer_t *fb);
-
-
-int flux_buffer_space (flux_buffer_t *fb);
-# 691 "/__w/flux-python/flux-python/src/_core_clean.h"
-int flux_buffer_readonly (flux_buffer_t *fb);
-bool flux_buffer_is_readonly (flux_buffer_t *fb);
-
-
-
-
-int flux_buffer_drop (flux_buffer_t *fb, int len);
-# 706 "/__w/flux-python/flux-python/src/_core_clean.h"
-const void *flux_buffer_peek (flux_buffer_t *fb, int len, int *lenp);
-# 716 "/__w/flux-python/flux-python/src/_core_clean.h"
-const void *flux_buffer_read (flux_buffer_t *fb, int len, int *lenp);
-
-
-
-
-int flux_buffer_write (flux_buffer_t *fb, const void *data, int len);
-
-
-
-int flux_buffer_lines (flux_buffer_t *fb);
-
-
-bool flux_buffer_has_line (flux_buffer_t *fb);
-
-
-
-int flux_buffer_drop_line (flux_buffer_t *fb);
-
-
-
-
-
-
-const void *flux_buffer_peek_line (flux_buffer_t *fb, int *lenp);
-
-
-
-const void *flux_buffer_peek_trimmed_line (flux_buffer_t *fb, int *lenp);
-
-
-
-
-
-
-const void *flux_buffer_read_line (flux_buffer_t *fb, int *lenp);
-
-
-
-const void *flux_buffer_read_trimmed_line (flux_buffer_t *fb, int *lenp);
-
-
-
-
-int flux_buffer_write_line (flux_buffer_t *fb, const char *data);
-
-
-
-
-int flux_buffer_peek_to_fd (flux_buffer_t *fb, int fd, int len);
-
-
-
-
-int flux_buffer_read_to_fd (flux_buffer_t *fb, int fd, int len);
-
-
-
-
-
-int flux_buffer_write_from_fd (flux_buffer_t *fb, int fd, int len);
-# 792 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 655 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_reactor flux_reactor_t;
 
 
@@ -544,11 +456,6 @@ enum {
 
 };
 
-
-enum {
-    FLUX_WATCHER_LINE_BUFFER = 1,
-};
-
 flux_reactor_t *flux_reactor_create (int flags);
 void flux_reactor_destroy (flux_reactor_t *r);
 
@@ -603,41 +510,6 @@ int flux_fd_watcher_get_fd (flux_watcher_t *w);
 
 
 
-
-
-flux_watcher_t *flux_buffer_read_watcher_create (flux_reactor_t *r, int fd,
-                                                 int size, flux_watcher_f cb,
-                                                 int flags, void *arg);
-
-flux_buffer_t *flux_buffer_read_watcher_get_buffer (flux_watcher_t *w);
-
-
-
-
-const char *flux_buffer_read_watcher_get_data (flux_watcher_t *w,
-                                               int *lenp);
-
-
-
-
-void flux_buffer_read_watcher_incref (flux_watcher_t *w);
-void flux_buffer_read_watcher_decref (flux_watcher_t *w);
-
-
-flux_watcher_t *flux_buffer_write_watcher_create (flux_reactor_t *r, int fd,
-                                                  int size, flux_watcher_f cb,
-                                                  int flags, void *arg);
-
-flux_buffer_t *flux_buffer_write_watcher_get_buffer (flux_watcher_t *w);
-# 904 "/__w/flux-python/flux-python/src/_core_clean.h"
-int flux_buffer_write_watcher_close (flux_watcher_t *w);
-
-
-int flux_buffer_write_watcher_is_closed (flux_watcher_t *w, int *close_err);
-
-
-
-
 flux_watcher_t *flux_timer_watcher_create (flux_reactor_t *r,
                                            double after, double repeat,
                                            flux_watcher_f cb, void *arg);
@@ -707,7 +579,7 @@ struct flux_watcher_ops {
     void (*stop) (flux_watcher_t *w);
     void (*destroy) (flux_watcher_t *w);
 };
-# 989 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 803 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_watcher_t * flux_watcher_create (flux_reactor_t *r, size_t data_size,
                                       struct flux_watcher_ops *ops,
                                       flux_watcher_f fn, void *arg);
@@ -719,7 +591,7 @@ void * flux_watcher_get_data (flux_watcher_t *w);
 
 
 struct flux_watcher_ops * flux_watcher_get_ops (flux_watcher_t *w);
-# 1028 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 842 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_msg_handler flux_msg_handler_t;
 
 typedef void (*flux_msg_handler_f)(flux_t *h, flux_msg_handler_t *mh,
@@ -766,7 +638,7 @@ void flux_msg_handler_delvec (flux_msg_handler_t *msg_handlers[]);
 
 
 int flux_dispatch_requeue (flux_t *h);
-# 1105 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 919 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef flux_t *(connector_init_f)(const char *uri,
                                    int flags,
                                    flux_error_t *errp);
@@ -799,7 +671,7 @@ flux_t *flux_handle_create (void *impl,
                             const struct flux_handle_ops *ops,
                             int flags);
 void flux_handle_destroy (flux_t *hp);
-# 1168 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 982 "/__w/flux-python/flux-python/src/_core_clean.h"
 struct flux_msglist *flux_msglist_create (void);
 void flux_msglist_destroy (struct flux_msglist *l);
 
@@ -813,10 +685,10 @@ const flux_msg_t *flux_msglist_next (struct flux_msglist *l);
 const flux_msg_t *flux_msglist_last (struct flux_msglist *l);
 
 int flux_msglist_count (struct flux_msglist *l);
-# 1189 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1003 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_msglist_pollevents (struct flux_msglist *l);
 int flux_msglist_pollfd (struct flux_msglist *l);
-# 1225 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1039 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_request_decode (const flux_msg_t *msg, const char **topic,
                          const char **s);
 
@@ -847,11 +719,11 @@ flux_msg_t *flux_request_encode (const char *topic, const char *s);
 
 flux_msg_t *flux_request_encode_raw (const char *topic,
                                      const void *data, int len);
-# 1291 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1105 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_response_decode (const flux_msg_t *msg,
                           const char **topic,
                           const char **s);
-# 1303 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1117 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_response_decode_raw (const flux_msg_t *msg,
                               const char **topic,
                               const void **data,
@@ -916,11 +788,11 @@ int flux_respond_error (flux_t *h,
                         const flux_msg_t *request,
                         int errnum,
                         const char *errstr);
-# 1395 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1209 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_msg_t *flux_control_encode (int type, int status);
 
 int flux_control_decode (const flux_msg_t *msg, int *type, int *status);
-# 1456 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1270 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef void (*flux_log_f)(const char *buf, int len, void *arg);
 
 
@@ -972,7 +844,7 @@ void flux_llog (void *arg,
                 int level,
                 const char *fmt,
                 va_list ap);
-# 1526 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1340 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_future flux_future_t;
 
 typedef void (*flux_continuation_f)(flux_future_t *f, void *arg);
@@ -1038,7 +910,7 @@ const char * flux_future_first_child (flux_future_t *cf);
 const char * flux_future_next_child (flux_future_t *cf);
 
 flux_future_t *flux_future_get_child (flux_future_t *cf, const char *name);
-# 1604 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1418 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_future_and_then (flux_future_t *f,
                                      flux_continuation_f cb, void *arg);
 
@@ -1066,7 +938,7 @@ void flux_future_continue_error (flux_future_t *prev, int errnum,
 int flux_future_fulfill_next (flux_future_t *prev,
                               void *result,
                               flux_free_f free_fn);
-# 1646 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1460 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum {
     FLUX_RPC_NORESPONSE = 1,
     FLUX_RPC_STREAMING = 2,
@@ -1117,7 +989,7 @@ uint32_t flux_rpc_get_matchtag (flux_future_t *f);
 
 
 uint32_t flux_rpc_get_nodeid (flux_future_t *f);
-# 1724 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1538 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum event_flags {
     FLUX_EVENT_PRIVATE = 1,
 };
@@ -1198,7 +1070,7 @@ flux_future_t *flux_event_publish_raw (flux_t *h,
 
 
 int flux_event_publish_get_seq (flux_future_t *f, int *seq);
-# 1835 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1649 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum {
     FLUX_MODSTATE_INIT = 0,
     FLUX_MODSTATE_RUNNING = 1,
@@ -1224,7 +1096,7 @@ bool flux_module_debug_test (flux_t *h, int flag, bool clear);
 
 
 int flux_module_set_running (flux_t *h);
-# 1908 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1722 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_attr_get (flux_t *h, const char *name);
 
 
@@ -1263,7 +1135,7 @@ const char *flux_get_hostbyrank (flux_t *h, uint32_t rank);
 
 
 int flux_get_rankbyhost (flux_t *h, const char *host);
-# 1960 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1774 "/__w/flux-python/flux-python/src/_core_clean.h"
 char *flux_hostmap_lookup (flux_t *h,
                            const char *targets,
                            flux_error_t *errp);
@@ -1274,7 +1146,7 @@ char *flux_hostmap_lookup (flux_t *h,
 
 
 int flux_get_instance_starttime (flux_t *h, double *starttime);
-# 1998 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1812 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum flux_conf_flags {
     FLUX_CONF_INSTALLED=0,
     FLUX_CONF_INTREE=1,
@@ -1327,13 +1199,13 @@ int flux_conf_vunpack (const flux_conf_t *conf,
 int flux_conf_unpack (const flux_conf_t *conf,
                       flux_error_t *error,
                       const char *fmt, ...);
-# 2082 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1896 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_barrier (flux_t *h, const char *name, int nprocs);
-# 2125 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1939 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_service_register (flux_t *h, const char *name);
-# 2137 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 1951 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_service_unregister (flux_t *h, const char *name);
-# 2189 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2003 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_core_version_string (void);
 
 
@@ -1342,7 +1214,7 @@ const char *flux_core_version_string (void);
 
 
 int flux_core_version (int *major, int *minor, int *patch);
-# 2227 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2041 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum {
     FLUX_PLUGIN_RTLD_LAZY = 1,
     FLUX_PLUGIN_RTLD_NOW = 2,
@@ -1420,7 +1292,7 @@ flux_plugin_f flux_plugin_match_handler (flux_plugin_t *p, const char *topic);
 int flux_plugin_register (flux_plugin_t *p,
                           const char *name,
                           const struct flux_plugin_handler t[]);
-# 2314 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2128 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_plugin_aux_set (flux_plugin_t *p,
                          const char *key,
                          void *val,
@@ -1482,14 +1354,14 @@ int flux_plugin_arg_unpack (flux_plugin_arg_t *args, int flags,
                             const char *fmt, ...);
 int flux_plugin_arg_vunpack (flux_plugin_arg_t *args, int flags,
                              const char *fmt, va_list ap);
-# 2383 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2197 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_plugin_call (flux_plugin_t *p, const char *name,
                       flux_plugin_arg_t *args);
-# 2393 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2207 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_plugin_load_dso (flux_plugin_t *p, const char *path);
-# 2426 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2240 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_sync_create (flux_t *h, double minimum);
-# 2458 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2272 "/__w/flux-python/flux-python/src/_core_clean.h"
 bool flux_disconnect_match (const flux_msg_t *msg1, const flux_msg_t *msg2);
 
 
@@ -1509,7 +1381,7 @@ bool flux_cancel_match (const flux_msg_t *msg1, const flux_msg_t *msg2);
 int flux_msglist_cancel (flux_t *h,
                          struct flux_msglist *l,
                          const flux_msg_t *msg);
-# 2527 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2341 "/__w/flux-python/flux-python/src/_core_clean.h"
 void flux_stats_count (flux_t *h, const char *name, ssize_t count);
 
 
@@ -1545,10 +1417,10 @@ void flux_stats_set_prefix (flux_t *h, const char *fmt, ...);
 
 
 bool flux_stats_enabled (flux_t *h, const char *metric);
-# 2610 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2424 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_kvsdir flux_kvsdir_t;
 typedef struct flux_kvsitr flux_kvsitr_t;
-# 2625 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2439 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_kvsdir_t *flux_kvsdir_create (flux_t *handle,
                                    const char *rootref,
                                    const char *key,
@@ -1596,7 +1468,7 @@ const char *flux_kvsdir_rootref (const flux_kvsdir_t *dir);
 
 
 char *flux_kvsdir_key_at (const flux_kvsdir_t *dir, const char *key);
-# 2700 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2514 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_lookup (flux_t *h,
                                 const char *ns,
                                 int flags,
@@ -1623,14 +1495,14 @@ const char *flux_kvs_lookup_get_key (flux_future_t *f);
 
 
 int flux_kvs_lookup_cancel (flux_future_t *f);
-# 2754 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2568 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_getroot (flux_t *h, const char *ns, int flags);
-# 2763 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2577 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_kvs_getroot_get_treeobj (flux_future_t *f, const char **treeobj);
 int flux_kvs_getroot_get_blobref (flux_future_t *f, const char **blobref);
 int flux_kvs_getroot_get_sequence (flux_future_t *f, int *seq);
 int flux_kvs_getroot_get_owner (flux_future_t *f, uint32_t *owner);
-# 2795 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2609 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_kvs_txn flux_kvs_txn_t;
 
 flux_kvs_txn_t *flux_kvs_txn_create (void);
@@ -1681,7 +1553,7 @@ int flux_kvs_txn_symlink (flux_kvs_txn_t *txn,
 int flux_kvs_txn_clear (flux_kvs_txn_t *txn);
 
 bool flux_kvs_txn_is_empty (flux_kvs_txn_t *txn);
-# 2894 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2708 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum kvs_commit_flags {
     FLUX_KVS_NO_MERGE = 1,
     FLUX_KVS_TXN_COMPACT = 2,
@@ -1704,21 +1576,21 @@ flux_future_t *flux_kvs_fence (flux_t *h,
 int flux_kvs_commit_get_treeobj (flux_future_t *f, const char **treeobj);
 int flux_kvs_commit_get_rootref (flux_future_t *f, const char **rootref);
 int flux_kvs_commit_get_sequence (flux_future_t *f, int *rootseq);
-# 2955 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2769 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_copy (flux_t *h,
                               const char *srcns,
                               const char *srckey,
                               const char *dstns,
                               const char *dstkey,
                               int commit_flags);
-# 2972 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2786 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_move (flux_t *h,
                               const char *srcns,
                               const char *srckey,
                               const char *dstns,
                               const char *dstkey,
                               int commit_flags);
-# 2995 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2809 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum kvs_op {
     FLUX_KVS_READDIR = 1,
     FLUX_KVS_READLINK = 2,
@@ -1730,7 +1602,7 @@ enum kvs_op {
     FLUX_KVS_WATCH_UNIQ = 128,
     FLUX_KVS_WATCH_APPEND = 256
 };
-# 3016 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2830 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_future_t *flux_kvs_namespace_create (flux_t *h,
                                           const char *ns,
                                           uint32_t owner,
@@ -1754,7 +1626,7 @@ int flux_kvs_wait_version (flux_t *h, const char *ns, int version);
 
 
 int flux_kvs_dropcache (flux_t *h);
-# 3067 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2881 "/__w/flux-python/flux-python/src/_core_clean.h"
 enum job_submit_flags {
     FLUX_JOB_PRE_SIGNED = 1,
     FLUX_JOB_DEBUG = 2,
@@ -1820,10 +1692,10 @@ typedef uint64_t flux_jobid_t;
 
 
 int flux_job_id_parse (const char *s, flux_jobid_t *id);
-# 3141 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2955 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_job_id_encode (flux_jobid_t id, const char *type,
                         char *buf, size_t bufsz);
-# 3152 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2966 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_job_statetostr (flux_job_state_t state, const char *fmt);
 
 
@@ -1937,16 +1809,16 @@ flux_future_t *flux_job_result (flux_t *h, flux_jobid_t id, int flags);
 
 int flux_job_result_get (flux_future_t *f,
                          const char **json_str);
-# 3283 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3097 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_job_result_get_unpack (flux_future_t *f, const char *fmt, ...);
-# 3297 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3111 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_job_timeleft (flux_t *h, flux_error_t *errp, double *timeleft);
-# 3313 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3127 "/__w/flux-python/flux-python/src/_core_clean.h"
 char *flux_unwrap_string (const char *in,
                           bool verify,
                           uint32_t *userid,
                           flux_error_t *error);
-# 3341 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3155 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_jobspec1 flux_jobspec1_t;
 typedef flux_error_t flux_jobspec1_error_t;
 
@@ -2044,7 +1916,7 @@ char *flux_jobspec1_encode (flux_jobspec1_t *jobspec, size_t flags);
 
 flux_jobspec1_t *flux_jobspec1_decode (const char *s,
                                        flux_jobspec1_error_t *error);
-# 3452 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3266 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_jobspec1_t *flux_jobspec1_from_command (int argc,
                                              char **argv,
                                              char **env,
@@ -2056,17 +1928,98 @@ flux_jobspec1_t *flux_jobspec1_from_command (int argc,
 
 
 void flux_jobspec1_destroy (flux_jobspec1_t *jobspec);
-# 3494 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3322 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_command flux_cmd_t;
 
 
 
 
+flux_cmd_t * flux_cmd_create (int argc, char *argv[], char **env);
 
 
 
+
+flux_cmd_t * flux_cmd_copy (const flux_cmd_t *cmd);
+
+
+
+
+void flux_cmd_destroy (flux_cmd_t *cmd);
+
+
+
+
+int flux_cmd_argv_appendf (flux_cmd_t *cmd,
+             const char *fmt, ...)
+                           ;
+
+
+
+
+int flux_cmd_argv_append (flux_cmd_t *cmd, const char *arg);
+
+
+
+
+int flux_cmd_argv_delete (flux_cmd_t *cmd, int n);
+
+
+
+
+int flux_cmd_argv_insert (flux_cmd_t *cmd, int n, const char *arg);
+
+
+
+
+int flux_cmd_argc (const flux_cmd_t *cmd);
+
+
+
+
+const char *flux_cmd_arg (const flux_cmd_t *cmd, int n);
+
+
+
+
+char *flux_cmd_stringify (const flux_cmd_t *cmd);
+
+
+
+
+
+int flux_cmd_setenvf (flux_cmd_t *cmd,
+        int overwrite,
+                      const char *name,
+        const char *fmt,
+        ...)
+                      ;
+
+
+
+
+
+void flux_cmd_unsetenv (flux_cmd_t *cmd, const char *name);
+
+
+
+
+
+
+const char *flux_cmd_getenv (const flux_cmd_t *cmd, const char *name);
+
+
+
+
+int flux_cmd_setcwd (flux_cmd_t *cmd, const char *cwd);
+const char *flux_cmd_getcwd (const flux_cmd_t *cmd);
+# 3418 "/__w/flux-python/flux-python/src/_core_clean.h"
+int flux_cmd_add_channel (flux_cmd_t *cmd, const char *name);
+# 3471 "/__w/flux-python/flux-python/src/_core_clean.h"
+int flux_cmd_setopt (flux_cmd_t *cmd, const char *var, const char *val);
+const char *flux_cmd_getopt (flux_cmd_t *cmd, const char *var);
+# 3490 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_subprocess flux_subprocess_t;
-# 3514 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3502 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef enum {
     FLUX_SUBPROCESS_INIT,
     FLUX_SUBPROCESS_RUNNING,
@@ -2139,89 +2092,9 @@ typedef void (*subprocess_log_f) (void *arg,
                                   int level,
                                   const char *fmt,
                                   va_list args);
-# 3598 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3586 "/__w/flux-python/flux-python/src/_core_clean.h"
 void flux_standard_output (flux_subprocess_t *p, const char *stream);
-# 3607 "/__w/flux-python/flux-python/src/_core_clean.h"
-flux_cmd_t * flux_cmd_create (int argc, char *argv[], char **env);
-
-
-
-
-flux_cmd_t * flux_cmd_copy (const flux_cmd_t *cmd);
-
-
-
-
-void flux_cmd_destroy (flux_cmd_t *cmd);
-
-
-
-
-int flux_cmd_argv_appendf (flux_cmd_t *cmd, const char *fmt, ...)
-                           ;
-
-
-
-
-int flux_cmd_argv_append (flux_cmd_t *cmd, const char *arg);
-
-
-
-
-int flux_cmd_argv_delete (flux_cmd_t *cmd, int n);
-
-
-
-
-int flux_cmd_argv_insert (flux_cmd_t *cmd, int n, const char *arg);
-
-
-
-
-int flux_cmd_argc (const flux_cmd_t *cmd);
-
-
-
-
-const char *flux_cmd_arg (const flux_cmd_t *cmd, int n);
-
-
-
-
-char *flux_cmd_stringify (const flux_cmd_t *cmd);
-
-
-
-
-
-int flux_cmd_setenvf (flux_cmd_t *cmd, int overwrite,
-                      const char *name, const char *fmt, ...)
-                      ;
-
-
-
-
-
-void flux_cmd_unsetenv (flux_cmd_t *cmd, const char *name);
-
-
-
-
-
-
-const char *flux_cmd_getenv (const flux_cmd_t *cmd, const char *name);
-
-
-
-
-int flux_cmd_setcwd (flux_cmd_t *cmd, const char *cwd);
-const char *flux_cmd_getcwd (const flux_cmd_t *cmd);
-# 3694 "/__w/flux-python/flux-python/src/_core_clean.h"
-int flux_cmd_add_channel (flux_cmd_t *cmd, const char *name);
-# 3747 "/__w/flux-python/flux-python/src/_core_clean.h"
-int flux_cmd_setopt (flux_cmd_t *cmd, const char *var, const char *val);
-const char *flux_cmd_getopt (flux_cmd_t *cmd, const char *var);
-# 3770 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3608 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_subprocess_t *flux_local_exec (flux_reactor_t *r,
                                     int flags,
                                     const flux_cmd_t *cmd,
@@ -2235,7 +2108,9 @@ flux_subprocess_t *flux_local_exec_ex (flux_reactor_t *r,
                                        subprocess_log_f log_fn,
                                        void *log_data);
 
-flux_subprocess_t *flux_rexec (flux_t *h, int rank, int flags,
+flux_subprocess_t *flux_rexec (flux_t *h,
+                 int rank,
+          int flags,
                                const flux_cmd_t *cmd,
                                const flux_subprocess_ops_t *ops);
 
@@ -2247,13 +2122,15 @@ flux_subprocess_t *flux_rexec_ex (flux_t *h,
                                   const flux_subprocess_ops_t *ops,
                                   subprocess_log_f log_fn,
                                   void *log_data);
-# 3805 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3645 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_subprocess_stream_start (flux_subprocess_t *p, const char *stream);
 int flux_subprocess_stream_stop (flux_subprocess_t *p, const char *stream);
 int flux_subprocess_stream_status (flux_subprocess_t *p, const char *stream);
-# 3818 "/__w/flux-python/flux-python/src/_core_clean.h"
-int flux_subprocess_write (flux_subprocess_t *p, const char *stream,
-                           const char *buf, size_t len);
+# 3658 "/__w/flux-python/flux-python/src/_core_clean.h"
+int flux_subprocess_write (flux_subprocess_t *p,
+             const char *stream,
+                           const char *buf,
+      size_t len);
 
 
 
@@ -2261,11 +2138,12 @@ int flux_subprocess_write (flux_subprocess_t *p, const char *stream,
 
 
 int flux_subprocess_close (flux_subprocess_t *p, const char *stream);
-# 3839 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3681 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_subprocess_read (flux_subprocess_t *p,
                                   const char *stream,
-                                  int len, int *lenp);
-# 3854 "/__w/flux-python/flux-python/src/_core_clean.h"
+                                  int len,
+      int *lenp);
+# 3697 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_subprocess_read_line (flux_subprocess_t *p,
                                        const char *stream,
                                        int *lenp);
@@ -2276,10 +2154,10 @@ const char *flux_subprocess_read_line (flux_subprocess_t *p,
 const char *flux_subprocess_read_trimmed_line (flux_subprocess_t *p,
                                                const char *stream,
                                                int *lenp);
-# 3874 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3717 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_subprocess_read_stream_closed (flux_subprocess_t *p,
                                         const char *stream);
-# 3893 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3736 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_subprocess_getline (flux_subprocess_t *p,
                                      const char *stream,
                                      int *lenp);
@@ -2299,7 +2177,7 @@ flux_future_t *flux_subprocess_kill (flux_subprocess_t *p, int signo);
 
 void flux_subprocess_ref (flux_subprocess_t *p);
 void flux_subprocess_unref (flux_subprocess_t *p);
-# 3920 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3763 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_subprocess_state_t flux_subprocess_state (flux_subprocess_t *p);
 
 
@@ -2346,7 +2224,9 @@ flux_reactor_t * flux_subprocess_get_reactor (flux_subprocess_t *p);
 
 
 int flux_subprocess_aux_set (flux_subprocess_t *p,
-                             const char *name, void *ctx, flux_free_f free);
+                             const char *name,
+        void *ctx,
+        flux_free_f free);
 
 
 
@@ -2361,7 +2241,7 @@ void *flux_subprocess_aux_get (flux_subprocess_t *p, const char *name);
 
 void flux_subprocess_channel_incref (flux_subprocess_t *p, const char *name);
 void flux_subprocess_channel_decref (flux_subprocess_t *p, const char *name);
-# 3994 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3839 "/__w/flux-python/flux-python/src/_core_clean.h"
 extern "Python" void message_handler_wrapper(flux_t *, flux_msg_handler_t *, const flux_msg_t *, void *);
 
 
@@ -2371,3 +2251,6 @@ extern "Python" void signal_handler_wrapper(flux_reactor_t *, flux_watcher_t *,
 
 
 extern "Python" void continuation_callback(flux_future_t *, void *);
+
+
+extern "Python" void init_callback(flux_future_t *, void *);
